@@ -1,6 +1,6 @@
 /*
     EvilAlarm
-    Copyright (C) 2010 Christian Pulvermacher
+    Copyright (C) 2010-2011 Christian Pulvermacher
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include "alarm.h"
 #include "daemon.h"
 #include "mainwindow.h"
+#include "module_list.h"
 #include "settings.h"
 
 #include <QtMaemo5>
@@ -77,9 +78,9 @@ MainWindow::MainWindow(QWidget *parent) :
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About EvilAlarm"),
-		tr("<center><h1>EvilAlarm 0.4</h1>\
+		tr("<center><h1>EvilAlarm 0.5</h1>\
 An alarm clock which cannot be turned off while asleep\
-<small><p>&copy;2010 Christian Pulvermacher &lt;pulvermacher@gmx.de&gt</p></small></center>\
+<small><p>&copy;2010, 2011 Christian Pulvermacher &lt;pulvermacher@gmx.de&gt;</p></small></center>\
 <p>This program is free software; License: <a href=\"http://www.gnu.org/licenses/gpl-2.0.html\">GNU GPL 2</a> or later.</p>"));
 }
 
@@ -99,7 +100,7 @@ void MainWindow::testAlarm()
 	//- hangs (after ~Backend() is finished????)
 	//maybe i should just use a --test parameter so it works exactly like --wakeup
 
-	Alarm* test_alarm = Alarm::getModuleInstance(this);
+	Alarm* test_alarm = ModuleList::getModuleInstance(this);
 	test_alarm->exec();
 	delete test_alarm;
 
